==> maxdb-source-7_5_00_38.tgz: V75_00_38/MaxDB_ORG/sys/src/gg/hgg08.h <==
/*!******************************************************************************

  @file         hgg08.h

  ------------------------------------------------------------------------------

  @author       <unknown>

  @brief        <unknown topic>

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2005 SAP AG
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
\endif

********************************************************************************/

#ifndef HGG08_H
#define HGG08_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\x91\x22\x04\xf5\x08\x9b\x3a\x78\x8e\xf9\x34\x90\xa1\xd8\x2a\x81'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tsp00_RegionId g08backup;
externPascal tsp00_RegionId g08datawrtr;
externPascal tsp00_RegionId g08objcontf;
externPascal tsp00_RegionId g08config;
externPascal tsp00_RegionId g08convert0;
externPascal tsp00_RegionId g08data1;
externPascal tsp00_RegionId g08datacache;
externPascal tsp00_RegionId g08dcom;
externPascal tsp00_RegionId g08diagcache;
externPascal tsp00_RegionId g08fbm;
externPascal tsp00_RegionId g08garbage;
externPascal tsp00_RegionId g08hashinit;
externPascal tsp00_RegionId g08lock0;
externPascal tsp00_RegionId g08lockinit;
externPascal tsp00_RegionId g08lockpool;
externPascal tsp00_RegionId g08lockreq;
externPascal tsp00_RegionId g08lockwait;
externPascal tsp00_RegionId g08savepoint;
externPascal tsp00_RegionId g08logqueue0;
externPascal tsp00_RegionId g08loginfo;
externPascal tsp00_RegionId g08LVCEmergency;
externPascal tsp00_RegionId g08history0;
externPascal tsp00_RegionId g08logwriter;
externPascal tsp00_RegionId g08monitor;
externPascal tsp00_RegionId g08history;
externPascal tsp00_RegionId g08oms1;
externPascal tsp00_RegionId g08permfdir;
externPascal tsp00_RegionId g08save0;
externPascal tsp00_RegionId g08server;
externPascal tsp00_RegionId g08surrogate;
externPascal tsp00_RegionId g08trace;
externPascal tsp00_RegionId g08ConvIndex;
externPascal tsp00_RegionId g08ConvWaitQueue;
externPascal tsp00_RegionId g08ComponentEnd;
externPascal tsp00_RegionId g08LockParallel;
externPascal tsp00_RegionId g08redocontrol;

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08check_excl (
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08excl_check (
    tsp00_TaskId             pid,
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08region_ids ();

/* Don't edit this file by hand, it is generated by ptocProto.py */


#endif

==> maxdb-source-7_6_00_09.tgz: V76_00_09/MaxDB_ORG/sys/src/gg/hgg08.h <==
/*!******************************************************************************

  @file         hgg08.h

  ------------------------------------------------------------------------------

  @author       ElkeZ

  @brief        Regions_and_Longwaits

\if EMIT_LICENCE

    ========== licence begin  GPL
    Copyright (c) 2000-2004 SAP AG
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end
\endif

********************************************************************************/

#ifndef HGG08_H
#define HGG08_H


/*===========================================================================*
 *     RefType: C++                                                          *
 *===========================================================================*/

/*===========================================================================*
 *     MD5: '\x0d\x96\xe0\x83\x89\xa2\xc0\x21\xea\x6b\x67\x8b\xfd\xf8\x33\xcd'
 *===========================================================================*/


/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externPascal tsp00_RegionId g08backup;
externPascal tsp00_RegionId g08datawrtr;
externPascal tsp00_RegionId g08objcontf;
externPascal tsp00_RegionId g08config;
externPascal tsp00_RegionId g08convert0;
externPascal tsp00_RegionId g08data1;
externPascal tsp00_RegionId g08datacache;
externPascal tsp00_RegionId g08dcom;
externPascal tsp00_RegionId g08diagcache;
externPascal tsp00_RegionId g08fbm;
externPascal tsp00_RegionId g08garbage;
externPascal tsp00_RegionId g08hashinit;
externPascal tsp00_RegionId g08lock0;
externPascal tsp00_RegionId g08lockinit;
externPascal tsp00_RegionId g08lockpool;
externPascal tsp00_RegionId g08lockreq;
externPascal tsp00_RegionId g08lockwait;
externPascal tsp00_RegionId g08savepoint;
externPascal tsp00_RegionId g08logqueue0;
externPascal tsp00_RegionId g08loginfo;
externPascal tsp00_RegionId g08LVCEmergency;
externPascal tsp00_RegionId g08history0;
externPascal tsp00_RegionId g08logwriter;
externPascal tsp00_RegionId g08monitor;
externPascal tsp00_RegionId g08history;
externPascal tsp00_RegionId g08oms1;
externPascal tsp00_RegionId g08save0;
externPascal tsp00_RegionId g08server;
externPascal tsp00_RegionId g08servertask;
externPascal tsp00_RegionId g08surrogate;
externPascal tsp00_RegionId g08trace;
externPascal tsp00_RegionId g08ConvIndex;
externPascal tsp00_RegionId g08KnlWaitQueue;
externPascal tsp00_RegionId g08ComponentEnd;
externPascal tsp00_RegionId g08LockParallel;
externPascal tsp00_RegionId g08ClusterIO;

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08check_excl (
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08excl_check (
    tsp00_TaskId             pid,
    tsp00_RegionId           region);

/* Don't edit this file by hand, it is generated by ptocProto.py */

externPascal void g08region_ids ();

/* Don't edit this file by hand, it is generated by ptocProto.py */


#endif
